@echo off
rem -------------------------------------------------------------------------------
rem Configure WebSphere MQ authorizations for topology discovery
rem
rem Arguments: -g queueManagerName RITEntity puttingApplicationEntity
rem
rem -g
rem          Group mode. Set authorizations for groups instead of users. 
rem          Defaults to setting authorizations for users. (Optional)
rem queueManagerName
rem          The name of the local queue manager to configure authorizations for.
rem RITEntity
rem          The user ID configured in the Websphere MQ observation point in
rem          Rational Integration Tester or, the name of a group that the user belongs
rem          to.
rem puttingApplicationEntity
rem          The user ID used by the existing application putting messages onto MQ queues or,
rem          the name of a group that the user belongs to.
rem -------------------------------------------------------------------------------

setlocal

rem ---- Check to see whether we should apply authorizations for users or groups
rem      Defaults to users ----
SET entityType=-p

if "%1"=="-g" (
    SET entityType=-g
    SHIFT
)

if "x%3x" == "xx" goto PrintUsage
if "x%4x" NEQ "xx" goto PrintUsage

rem Dump all existing queue manager authorities to file prior to running the setmqaut commands
dmpmqaut -m %1 > preExitRecordingAuthorityBackup.aut 2>&1

rem ---- Set authorizations to enable access for the MQ user configured in RIT ----
setmqaut -m %1 -t qmgr %entityType% "%2" +connect +inq +dsp
setmqaut -m %1 -t q -n SYSTEM.DEFAULT.MODEL.QUEUE %entityType% "%2" +get +dsp
setmqaut -m %1 -t q -n SYSTEM.ADMIN.COMMAND.QUEUE %entityType% "%2" +inq +put
setmqaut -m %1 -n SYSTEM.DEFAULT.NAMELIST -t namelist %entityType% "%2" +dsp
setmqaut -m %1 -n "**" -t namelist %entityType% "%2" +crt
setmqaut -m %1 -n "COM.GREENHAT.OBSERVATION*" -t namelist %entityType% "%2" +dsp +chg
setmqaut -m %1 -n "SYSTEM.DEFAULT.LOCAL.QUEUE" -t q %entityType% "%2" +dsp
setmqaut -m %1 -n "**" -t q %entityType% "%2" +crt
rem ---- Set authorizations to enable access for the MQ user used by the existing application ----
setmqaut -m %1 -t qmgr %entityType% "%3" +connect +inq +setall
setmqaut -m %1 -n "COM.GREENHAT.OBSERVATION*" -t namelist %entityType% "%3" +inq
setmqaut -m %1 -n "SYSTEM.DEFAULT.MODEL.QUEUE" -t q %entityType% "%3" +put +setall

goto End

:PrintUsage
echo arguments: [-g] queueManagerName RITEntity puttingApplicationEntity
echo -g
echo    Group mode. Set authorizations for groups instead of users. Defaults to setting authorizations for users. (Optional)
echo.
echo queueManagerName
echo    The name of the local queue manager to configure authorizations for.
echo.
echo RITEntity
echo    The user ID configured in the physical resource in Rational Integration Tester or, the name of a group that the user belongs to.
echo.
echo puttingApplicationEntity
echo    The user ID used by the existing application putting messages onto MQ queues or, the name of a group that the user belongs to.
:End

endlocal
BLAH BLAH BLAH
BLAH 

